@@ -33,6 +33,9 @@ func newPluginTemplateCmd(config *config.Config, plugin *plugins.Plugin) *plugin
 		Short:       plugin.Shortdesc,
 		RunE:        ptc.runPluginCmd,
 		Annotations: map[string]string{"scope": "plugin"},
+		FParseErrWhitelist: cobra.FParseErrWhitelist{
+			UnknownFlags: true,
+		},
 	}
 
 	// override the CLI's help command and let the plugin supply the help text instead
@@ -61,6 +64,10 @@ func (ptc *pluginTemplateCmd) runPluginCmd(cmd *cobra.Command, args []string) er
 		return err
 	}
 
+	log.WithFields(log.Fields{
+		"prefix": "cmd.pluginCmd.runPluginCmd",
+	}).Debug("Running plugin...")
+
 	err = plugin.Run(ctx, ptc.cfg, fs, ptc.ParsedArgs)
 	plugins.CleanupAllClients()
 
