@@ -2,6 +2,7 @@ package plugins
 
 import (
 	"context"
+	"fmt"
 	"os"
 	"testing"
 
@@ -27,7 +28,8 @@ func TestInstall(t *testing.T) {
 	plugin, _ := LookUpPlugin(context.Background(), config, fs, "appA")
 	err := plugin.Install(context.Background(), config, fs, "2.0.1", testServers.StripeServer.URL)
 	require.Nil(t, err)
-	fileExists, err := afero.Exists(fs, "/plugins/appA/2.0.1/stripe-cli-app-a")
+	file := fmt.Sprintf("/plugins/appA/2.0.1/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, err := afero.Exists(fs, file)
 	require.Nil(t, err)
 	require.True(t, fileExists)
 }
@@ -43,7 +45,8 @@ func TestInstallFailsIfChecksumCouldNotBeFound(t *testing.T) {
 	require.EqualError(t, err, "Could not locate a valid checksum for appA version 0.0.0")
 
 	// Require that we don't save the binary if checkum does not match
-	fileExists, err := afero.Exists(fs, "/plugins/appA/0.0.1/stripe-cli-app-a")
+	file := fmt.Sprintf("/plugins/appA/0.0.0/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, err := afero.Exists(fs, file)
 	require.Nil(t, err)
 	require.False(t, fileExists)
 }
@@ -59,7 +62,8 @@ func TestInstallationFailsIfChecksumDoesNotMatch(t *testing.T) {
 	require.EqualError(t, err, "installed plugin 'appB' could not be verified, aborting installation")
 
 	// Require that we don't save the binary if checkum does not match
-	fileExists, err := afero.Exists(fs, "/plugins/appB/1.2.1/stripe-cli-app-b")
+	file := fmt.Sprintf("/plugins/appB/1.2.1/stripe-cli-app-b%s", GetBinaryExtension())
+	fileExists, err := afero.Exists(fs, file)
 	require.Nil(t, err)
 	require.False(t, fileExists)
 }
@@ -74,17 +78,19 @@ func TestInstallCleansOtherVersionsOfPlugin(t *testing.T) {
 	plugin, _ := LookUpPlugin(context.Background(), config, fs, "appA")
 	err := plugin.Install(context.Background(), config, fs, "0.0.1", testServers.StripeServer.URL)
 	require.Nil(t, err)
-	fileExists, _ := afero.Exists(fs, "/plugins/appA/0.0.1/stripe-cli-app-a")
+	file := fmt.Sprintf("/plugins/appA/0.0.1/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, _ := afero.Exists(fs, file)
 	require.True(t, fileExists, "Test setup failed -- did not download plugin version 0.0.1")
 
 	// Download valid plugin
 	err = plugin.Install(context.Background(), config, fs, "2.0.1", testServers.StripeServer.URL)
 	require.Nil(t, err)
-	fileExists, _ = afero.Exists(fs, "/plugins/appA/2.0.1/stripe-cli-app-a")
+	newFile := fmt.Sprintf("/plugins/appA/2.0.1/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, _ = afero.Exists(fs, newFile)
 	require.True(t, fileExists, "Test setup failed -- did not download plugin version 2.0.1")
 
 	// Require that the older version got removed from the fs
-	fileExists, _ = afero.Exists(fs, "/plugins/appA/0.0.1/stripe-cli-app-a")
+	fileExists, _ = afero.Exists(fs, file)
 	require.False(t, fileExists, "Expected the original version of the plugin to be deleted.")
 }
 
@@ -98,16 +104,18 @@ func TestInstallDoesNotCleanIfInstallFails(t *testing.T) {
 	plugin, _ := LookUpPlugin(context.Background(), config, fs, "appA")
 	err := plugin.Install(context.Background(), config, fs, "2.0.1", testServers.StripeServer.URL)
 	require.Nil(t, err)
-	fileExists, _ := afero.Exists(fs, "/plugins/appA/2.0.1/stripe-cli-app-a")
+	file := fmt.Sprintf("/plugins/appA/2.0.1/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, _ := afero.Exists(fs, file)
 	require.True(t, fileExists, "Test setup failed -- did not download valid plugin")
 
 	// Install fails for the same plugin because the checksum could not be found in manifest
 	err = plugin.Install(context.Background(), config, fs, "0.0.0", testServers.StripeServer.URL)
 	require.EqualError(t, err, "Could not locate a valid checksum for appA version 0.0.0")
-	fileExists, _ = afero.Exists(fs, "/plugins/appA/0.0.1/stripe-cli-app-a")
+	failedFile := fmt.Sprintf("/plugins/appA/0.0.0/stripe-cli-app-a%s", GetBinaryExtension())
+	fileExists, _ = afero.Exists(fs, failedFile)
 	require.False(t, fileExists, "Test setup failed -- did not expect plugin to be downloaded")
 
 	// Require that we did not delete the initial version of the plugin
-	fileExists, _ = afero.Exists(fs, "/plugins/appA/2.0.1/stripe-cli-app-a")
+	fileExists, _ = afero.Exists(fs, file)
 	require.True(t, fileExists, "Did not expect the original version of the plugin to be deleted.")
 }
